@@ -9,7 +9,7 @@ from distutils.filelist import glob_to_re, translate_pattern, FileList
 from distutils import filelist
 
 from test.support import os_helper
-from test.support import captured_stdout, run_unittest
+from test.support import captured_stdout
 from distutils.tests import support
 
 MANIFEST_IN = """\
@@ -329,12 +329,5 @@ class FindAllTestCase(unittest.TestCase):
             self.assertEqual(filelist.findall(temp_dir), expected)
 
 
-def test_suite():
-    return unittest.TestSuite([
-        unittest.TestLoader().loadTestsFromTestCase(FileListTestCase),
-        unittest.TestLoader().loadTestsFromTestCase(FindAllTestCase),
-    ])
-
-
 if __name__ == "__main__":
-    run_unittest(test_suite())
+    unittest.main()
